@@ -1,287 +1,285 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="es">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
 <context>
     <name>MXDateTime</name>
     <message>
-        <location filename="../datetime.ui" line="20"/>
-        <location filename="../datetime.cpp" line="596"/>
+        <location filename="datetime.ui" line="20"/>
+        <location filename="datetime.cpp" line="596"/>
         <source>MX Date &amp; Time</source>
         <translation>MX Fecha &amp; Hora</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="26"/>
+        <location filename="datetime.ui" line="26"/>
         <source>Close</source>
         <translation>Cerrar</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="40"/>
+        <location filename="datetime.ui" line="40"/>
         <source>Help</source>
         <translation>Ayuda</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="73"/>
+        <location filename="datetime.ui" line="73"/>
         <source>Apply</source>
         <translation>Aplicar</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="100"/>
+        <location filename="datetime.ui" line="100"/>
         <source>About...</source>
         <translation>Acerca de...</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="124"/>
+        <location filename="datetime.ui" line="124"/>
         <source>Date &amp;&amp; Time</source>
         <translation>Fecha &amp;&amp; Hora</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="192"/>
+        <location filename="datetime.ui" line="192"/>
         <source>H:mm:ss</source>
         <translation>H:mm:ss</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="278"/>
-        <location filename="../datetime.cpp" line="296"/>
-        <location filename="../datetime.cpp" line="303"/>
+        <location filename="datetime.ui" line="278"/>
+        <location filename="datetime.cpp" line="296"/>
+        <location filename="datetime.cpp" line="303"/>
         <source>Hardware Clock</source>
         <translation>Reloj de Hardware</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="284"/>
+        <location filename="datetime.ui" line="284"/>
         <source>Hardware Clock tools</source>
         <translation>Herramientas de Reloj de Hardware</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="290"/>
+        <location filename="datetime.ui" line="290"/>
         <source>Obtain information from the Hardware Clock and present it in the box below.</source>
         <translation>Obtenga información del Reloj de Hardware y preséntela en el cuadro a continuación.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="293"/>
+        <location filename="datetime.ui" line="293"/>
         <source>Read the Hardware Clock</source>
         <translation>Lea el Reloj de Hardware</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="303"/>
+        <location filename="datetime.ui" line="300"/>
         <source>Apply systematic drift corrections to the Hardware Clock.</source>
         <translation>Aplique correcciones de deriva sistemáticas al Reloj de Hardware.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="306"/>
+        <location filename="datetime.ui" line="303"/>
         <source>Drift Adjust</source>
         <translation>Ajuste de Deriva</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="329"/>
+        <location filename="datetime.ui" line="323"/>
         <source>Time transfer</source>
         <translation>Transferencia de tiempo</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="335"/>
+        <location filename="datetime.ui" line="329"/>
         <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
         <translation>Configure inmediatamente el reloj del sistema para que coincida con la hora actual registrada por el reloj de hardware.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="338"/>
+        <location filename="datetime.ui" line="332"/>
         <source>Hardware Clock to System Clock</source>
         <translation>Reloj de Hardware a Reloj del Sistema</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="348"/>
+        <location filename="datetime.ui" line="339"/>
         <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
         <translation>Configure inmediatamente el Reloj de Hardware para que coincida con la hora actual registrada por el Reloj del Sistema.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="351"/>
+        <location filename="datetime.ui" line="342"/>
         <source>System Clock to Hardware Clock</source>
         <translation>Reloj del Sistema al Reloj de Hardware</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="361"/>
+        <location filename="datetime.ui" line="349"/>
         <source>Update the drift factor for the Hardware Clock when it is being set.</source>
         <translation>Actualice el factor de deriva para el Reloj de Hardware cuando se este configurando.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="364"/>
+        <location filename="datetime.ui" line="352"/>
         <source>Update the drift</source>
         <translation>Actualizar la deriva</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="374"/>
+        <location filename="datetime.ui" line="362"/>
         <source>Time zone for the Hardware Clock</source>
         <translation>Zona horaria para el Reloj de Hardware</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="380"/>
+        <location filename="datetime.ui" line="368"/>
         <source>Local time</source>
         <translation>Hora local</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="383"/>
+        <location filename="datetime.ui" line="371"/>
         <source>Local</source>
         <translation>Local</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="390"/>
+        <location filename="datetime.ui" line="378"/>
         <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
         <translation>Tiempo Universalmente Coordinado (u Hora del Meridiano de Greenwich)</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="393"/>
+        <location filename="datetime.ui" line="381"/>
         <source>UTC</source>
         <translation>UTC</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="433"/>
+        <location filename="datetime.ui" line="421"/>
         <source>Network Time</source>
         <translation>Tiempo de Red</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="439"/>
+        <location filename="datetime.ui" line="427"/>
         <source>Move the selected item down</source>
         <translation>Mueve el elemento seleccionado hacia abajo</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="450"/>
+        <location filename="datetime.ui" line="438"/>
         <source>Move the selected item up</source>
         <translation>Mueve el elemento seleccionado hacia arriba</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="461"/>
+        <location filename="datetime.ui" line="449"/>
         <source>Remove the current item from the list</source>
         <translation>Eliminar el elemento actual de la lista</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="472"/>
+        <location filename="datetime.ui" line="460"/>
         <source>Add an item to the list</source>
         <translation>Agregar un elemento a la lista</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="498"/>
+        <location filename="datetime.ui" line="486"/>
         <source>Automatically update the System Clock with NTP servers:</source>
         <translation>Actualice automáticamente el Reloj del Sistema con servidores NTP:</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="505"/>
+        <location filename="datetime.ui" line="493"/>
         <source>Immediately update the system clock with NTP servers.</source>
         <translation>Actualice inmediatamente el reloj del sistema con servidores NTP.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="508"/>
+        <location filename="datetime.ui" line="496"/>
         <source>Update Now</source>
         <translation>Actualizar Ahora</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="520"/>
+        <location filename="datetime.ui" line="505"/>
         <source>List of NTP servers to use.</source>
         <translation>Lista de servidores NTP para usar.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="536"/>
+        <location filename="datetime.ui" line="521"/>
         <source>Type</source>
         <translation>Tipo</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="541"/>
+        <location filename="datetime.ui" line="526"/>
         <source>Address</source>
         <translation>Dirección</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="546"/>
+        <location filename="datetime.ui" line="531"/>
         <source>Options</source>
         <translation>Opciones</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="270"/>
+        <location filename="datetime.cpp" line="270"/>
         <source>Reading...</source>
         <translation>Leyendo...</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="284"/>
+        <location filename="datetime.cpp" line="284"/>
         <source>Adjusting...</source>
         <translation>Ajustándose...</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="296"/>
-        <location filename="../datetime.cpp" line="303"/>
+        <location filename="datetime.cpp" line="296"/>
+        <location filename="datetime.cpp" line="303"/>
         <source>System Clock</source>
         <translation>Reloj del Sistema</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="309"/>
+        <location filename="datetime.cpp" line="309"/>
         <source>The %1 time was transferred to the %2.</source>
         <translation>El tiempo %1 se transfirió al %2.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="312"/>
+        <location filename="datetime.cpp" line="312"/>
         <source>The %1 time could not be transferred to the %2.</source>
         <translation>El tiempo %1 no se pudo transferir al %2.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="350"/>
+        <location filename="datetime.cpp" line="350"/>
         <source>Updating...</source>
         <translation>Actualizando...</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="360"/>
+        <location filename="datetime.cpp" line="360"/>
         <source>The system clock was updated successfully.</source>
         <translation>El reloj del sistema se actualizó correctamente.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="362"/>
+        <location filename="datetime.cpp" line="362"/>
         <source>The system clock could not be updated.</source>
         <translation>El reloj del sistema no se pudo actualizar.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="364"/>
+        <location filename="datetime.cpp" line="364"/>
         <source>None of the NTP servers on the list are currently enabled.</source>
         <translation>Ninguno de los servidores NTP en la lista está habilitado actualmente.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="595"/>
+        <location filename="datetime.cpp" line="595"/>
         <source>About MX Date &amp; Time</source>
         <translation>Acerca de MX Fecha &amp; Hora</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="596"/>
+        <location filename="datetime.cpp" line="596"/>
         <source>Version: </source>
         <translation>Versión:</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="597"/>
+        <location filename="datetime.cpp" line="597"/>
         <source>GUI program for setting the time and date in MX Linux</source>
         <translation>Programa GUI para configurar la hora y la fecha en MX Linux</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="599"/>
+        <location filename="datetime.cpp" line="599"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="600"/>
-        <location filename="../datetime.cpp" line="614"/>
+        <location filename="datetime.cpp" line="600"/>
+        <location filename="datetime.cpp" line="614"/>
         <source>License</source>
         <translation>Licencia</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="601"/>
+        <location filename="datetime.cpp" line="601"/>
         <source>Changelog</source>
         <translation>Registro de cambios</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="602"/>
+        <location filename="datetime.cpp" line="602"/>
         <source>Cancel</source>
         <translation>Cancelar</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="628"/>
+        <location filename="datetime.cpp" line="628"/>
         <source>&amp;Close</source>
         <translation>&amp;Cerrar</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="646"/>
+        <location filename="datetime.cpp" line="646"/>
         <source>MX Date &amp; Time Help</source>
         <translation>MX Fecha &amp; Hora Ayuda</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
