@@ -1,287 +1,285 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="sl">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.1">
 <context>
     <name>MXDateTime</name>
     <message>
-        <location filename="../datetime.ui" line="20"/>
-        <location filename="../datetime.cpp" line="596"/>
+        <location filename="datetime.ui" line="20"/>
+        <location filename="datetime.cpp" line="596"/>
         <source>MX Date &amp; Time</source>
         <translation>MX Datum in ura</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="26"/>
+        <location filename="datetime.ui" line="26"/>
         <source>Close</source>
         <translation>Zapri</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="40"/>
+        <location filename="datetime.ui" line="40"/>
         <source>Help</source>
         <translation>Pomoč</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="73"/>
+        <location filename="datetime.ui" line="73"/>
         <source>Apply</source>
         <translation>Potrdi</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="100"/>
+        <location filename="datetime.ui" line="100"/>
         <source>About...</source>
         <translation>O programu...</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="124"/>
+        <location filename="datetime.ui" line="124"/>
         <source>Date &amp;&amp; Time</source>
         <translation>Datum &amp;&amp; ura</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="192"/>
+        <location filename="datetime.ui" line="192"/>
         <source>H:mm:ss</source>
         <translation>U:mm:ss</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="278"/>
-        <location filename="../datetime.cpp" line="296"/>
-        <location filename="../datetime.cpp" line="303"/>
+        <location filename="datetime.ui" line="278"/>
+        <location filename="datetime.cpp" line="296"/>
+        <location filename="datetime.cpp" line="303"/>
         <source>Hardware Clock</source>
         <translation>Strojna ura</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="284"/>
+        <location filename="datetime.ui" line="284"/>
         <source>Hardware Clock tools</source>
         <translation>Ordoja strojne ure</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="290"/>
+        <location filename="datetime.ui" line="290"/>
         <source>Obtain information from the Hardware Clock and present it in the box below.</source>
         <translation>Pridobi informacije od strojne ure in jih prikaže v spodnjem okvirju.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="293"/>
+        <location filename="datetime.ui" line="293"/>
         <source>Read the Hardware Clock</source>
         <translation>Odčitaj strojno uro</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="303"/>
+        <location filename="datetime.ui" line="300"/>
         <source>Apply systematic drift corrections to the Hardware Clock.</source>
         <translation>Sistemetične popravi odstopanja strojne ure.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="306"/>
+        <location filename="datetime.ui" line="303"/>
         <source>Drift Adjust</source>
         <translation>Nastavljanje odstopanja</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="329"/>
+        <location filename="datetime.ui" line="323"/>
         <source>Time transfer</source>
         <translation>Prenos časa</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="335"/>
+        <location filename="datetime.ui" line="329"/>
         <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
         <translation>Nemudoma nastavi sistemsko uro, da ustreza času, kot ga trenutno kaže strojna ura.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="338"/>
+        <location filename="datetime.ui" line="332"/>
         <source>Hardware Clock to System Clock</source>
         <translation>Strojna ura v sistemsko uro</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="348"/>
+        <location filename="datetime.ui" line="339"/>
         <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
         <translation>Nemudoma nastavi strojno uro, da ustreza času, kot ga trenutno kaže sistemska ura.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="351"/>
+        <location filename="datetime.ui" line="342"/>
         <source>System Clock to Hardware Clock</source>
         <translation>Sistemska ura v strojno uro</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="361"/>
+        <location filename="datetime.ui" line="349"/>
         <source>Update the drift factor for the Hardware Clock when it is being set.</source>
         <translation>Posodobi faktor odstopanja za strojno uro, potem ko je nastavljen.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="364"/>
+        <location filename="datetime.ui" line="352"/>
         <source>Update the drift</source>
         <translation>Posodobi ostopanje</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="374"/>
+        <location filename="datetime.ui" line="362"/>
         <source>Time zone for the Hardware Clock</source>
         <translation>Časovni pas za strojno uro</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="380"/>
+        <location filename="datetime.ui" line="368"/>
         <source>Local time</source>
         <translation>Lokalni čas</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="383"/>
+        <location filename="datetime.ui" line="371"/>
         <source>Local</source>
         <translation>Lokalno</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="390"/>
+        <location filename="datetime.ui" line="378"/>
         <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
         <translation>Univerzalni koordinirani čas (ali Greenwiški srednji čas)</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="393"/>
+        <location filename="datetime.ui" line="381"/>
         <source>UTC</source>
         <translation>UTC</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="433"/>
+        <location filename="datetime.ui" line="421"/>
         <source>Network Time</source>
         <translation>Omrežni čas</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="439"/>
+        <location filename="datetime.ui" line="427"/>
         <source>Move the selected item down</source>
         <translation>Premakni izbrani element navzdol</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="450"/>
+        <location filename="datetime.ui" line="438"/>
         <source>Move the selected item up</source>
         <translation>Premakni izbrani element navzgor</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="461"/>
+        <location filename="datetime.ui" line="449"/>
         <source>Remove the current item from the list</source>
         <translation>Odstrani trenutni element iz seznama</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="472"/>
+        <location filename="datetime.ui" line="460"/>
         <source>Add an item to the list</source>
         <translation>Dodaj element na seznam</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="498"/>
+        <location filename="datetime.ui" line="486"/>
         <source>Automatically update the System Clock with NTP servers:</source>
         <translation>Samodejno posodobi sistemsko uro preko NTP strežnikov:</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="505"/>
+        <location filename="datetime.ui" line="493"/>
         <source>Immediately update the system clock with NTP servers.</source>
         <translation>Nemudoma posodobi sistemsko uro preko NTP strežnikov.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="508"/>
+        <location filename="datetime.ui" line="496"/>
         <source>Update Now</source>
         <translation>Posodobi zdaj</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="520"/>
+        <location filename="datetime.ui" line="505"/>
         <source>List of NTP servers to use.</source>
         <translation>Seznam uporabljenih NTP strežnikov.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="536"/>
+        <location filename="datetime.ui" line="521"/>
         <source>Type</source>
         <translation>Vrsta</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="541"/>
+        <location filename="datetime.ui" line="526"/>
         <source>Address</source>
         <translation>Naslov</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="546"/>
+        <location filename="datetime.ui" line="531"/>
         <source>Options</source>
         <translation>Opcije</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="270"/>
+        <location filename="datetime.cpp" line="270"/>
         <source>Reading...</source>
         <translation>Odčitavanje...</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="284"/>
+        <location filename="datetime.cpp" line="284"/>
         <source>Adjusting...</source>
         <translation>Nastavljanje...</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="296"/>
-        <location filename="../datetime.cpp" line="303"/>
+        <location filename="datetime.cpp" line="296"/>
+        <location filename="datetime.cpp" line="303"/>
         <source>System Clock</source>
         <translation>Sistemska ura</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="309"/>
+        <location filename="datetime.cpp" line="309"/>
         <source>The %1 time was transferred to the %2.</source>
         <translation>Čas %1 je bil prenešen v %2.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="312"/>
+        <location filename="datetime.cpp" line="312"/>
         <source>The %1 time could not be transferred to the %2.</source>
         <translation>Časa %1 ni bilo mogoče prenesti v %2.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="350"/>
+        <location filename="datetime.cpp" line="350"/>
         <source>Updating...</source>
         <translation>Posodabljanje...</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="360"/>
+        <location filename="datetime.cpp" line="360"/>
         <source>The system clock was updated successfully.</source>
         <translation>Sistemska ura je bila uspešno posodobljena.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="362"/>
+        <location filename="datetime.cpp" line="362"/>
         <source>The system clock could not be updated.</source>
         <translation>Sistemske ure ni bilo mogoče posodobiti.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="364"/>
+        <location filename="datetime.cpp" line="364"/>
         <source>None of the NTP servers on the list are currently enabled.</source>
         <translation>Noben od NTP strežnikov iz seznama trenutno ni vklopljen.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="595"/>
+        <location filename="datetime.cpp" line="595"/>
         <source>About MX Date &amp; Time</source>
         <translation>O programu MX datum in ura</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="596"/>
+        <location filename="datetime.cpp" line="596"/>
         <source>Version: </source>
         <translation>Različica:</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="597"/>
+        <location filename="datetime.cpp" line="597"/>
         <source>GUI program for setting the time and date in MX Linux</source>
         <translation>Grafični program za nastavljanje ure in datuma v MX Linuxu</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="599"/>
+        <location filename="datetime.cpp" line="599"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="600"/>
-        <location filename="../datetime.cpp" line="614"/>
+        <location filename="datetime.cpp" line="600"/>
+        <location filename="datetime.cpp" line="614"/>
         <source>License</source>
         <translation>Licenca</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="601"/>
+        <location filename="datetime.cpp" line="601"/>
         <source>Changelog</source>
         <translation>Dnevnik sprememb</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="602"/>
+        <location filename="datetime.cpp" line="602"/>
         <source>Cancel</source>
         <translation>Prekliči</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="628"/>
+        <location filename="datetime.cpp" line="628"/>
         <source>&amp;Close</source>
         <translation>&amp;Zapri</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="646"/>
+        <location filename="datetime.cpp" line="646"/>
         <source>MX Date &amp; Time Help</source>
         <translation>Pomoč za MX datum in ura</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
