@@ -1,287 +1,285 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="sv">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="sv" version="2.1">
 <context>
     <name>MXDateTime</name>
     <message>
-        <location filename="../datetime.ui" line="20"/>
-        <location filename="../datetime.cpp" line="596"/>
+        <location filename="datetime.ui" line="20"/>
+        <location filename="datetime.cpp" line="596"/>
         <source>MX Date &amp; Time</source>
         <translation>MX Datum &amp; Tid</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="26"/>
+        <location filename="datetime.ui" line="26"/>
         <source>Close</source>
         <translation>Stäng</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="40"/>
+        <location filename="datetime.ui" line="40"/>
         <source>Help</source>
         <translation>Hjälp</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="73"/>
+        <location filename="datetime.ui" line="73"/>
         <source>Apply</source>
         <translation>Använd</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="100"/>
+        <location filename="datetime.ui" line="100"/>
         <source>About...</source>
         <translation>Om...</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="124"/>
+        <location filename="datetime.ui" line="124"/>
         <source>Date &amp;&amp; Time</source>
         <translation>Datum &amp;&amp; Tid</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="192"/>
+        <location filename="datetime.ui" line="192"/>
         <source>H:mm:ss</source>
         <translation>H:mm:ss</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="278"/>
-        <location filename="../datetime.cpp" line="296"/>
-        <location filename="../datetime.cpp" line="303"/>
+        <location filename="datetime.ui" line="278"/>
+        <location filename="datetime.cpp" line="296"/>
+        <location filename="datetime.cpp" line="303"/>
         <source>Hardware Clock</source>
         <translation>Hårdvaruklocka</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="284"/>
+        <location filename="datetime.ui" line="284"/>
         <source>Hardware Clock tools</source>
         <translation>Verktyg för Hårdvaruklocka</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="290"/>
+        <location filename="datetime.ui" line="290"/>
         <source>Obtain information from the Hardware Clock and present it in the box below.</source>
         <translation>Få information från Hårdvaruklockan och visa den i rutan nedanför.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="293"/>
+        <location filename="datetime.ui" line="293"/>
         <source>Read the Hardware Clock</source>
         <translation>Avläs Hårdvaruklockan</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="303"/>
+        <location filename="datetime.ui" line="300"/>
         <source>Apply systematic drift corrections to the Hardware Clock.</source>
         <translation>Använd korrektion för systematisk avdrift hos Hårdvaruklockan.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="306"/>
+        <location filename="datetime.ui" line="303"/>
         <source>Drift Adjust</source>
         <translation>Justera Avdrift</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="329"/>
+        <location filename="datetime.ui" line="323"/>
         <source>Time transfer</source>
         <translation>Tidsöverföring</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="335"/>
+        <location filename="datetime.ui" line="329"/>
         <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
         <translation>Ställ genast Systemklockan så den stämmer med den tid som nu registreras av Hårdvaruklockan.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="338"/>
+        <location filename="datetime.ui" line="332"/>
         <source>Hardware Clock to System Clock</source>
         <translation>Hårdvaruklocka till Systemklocka</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="348"/>
+        <location filename="datetime.ui" line="339"/>
         <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
         <translation>Ställ genast Hårdvaruklockan så den stämmer med den tid som nu registreras av Systemklockan.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="351"/>
+        <location filename="datetime.ui" line="342"/>
         <source>System Clock to Hardware Clock</source>
         <translation>Systemklocka till Hårdvaruklocka</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="361"/>
+        <location filename="datetime.ui" line="349"/>
         <source>Update the drift factor for the Hardware Clock when it is being set.</source>
         <translation>Uppdatera avdriftsfaktorn för Hårdvaruklockan när den ställs.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="364"/>
+        <location filename="datetime.ui" line="352"/>
         <source>Update the drift</source>
         <translation>Uppdatera avdriften</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="374"/>
+        <location filename="datetime.ui" line="362"/>
         <source>Time zone for the Hardware Clock</source>
         <translation>Tidszon för Hårdvaruklocka</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="380"/>
+        <location filename="datetime.ui" line="368"/>
         <source>Local time</source>
         <translation>Lokal tid</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="383"/>
+        <location filename="datetime.ui" line="371"/>
         <source>Local</source>
         <translation>Lokal</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="390"/>
+        <location filename="datetime.ui" line="378"/>
         <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
         <translation>Universally Coordinated Time (eller Greenwich Meridian Time)</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="393"/>
+        <location filename="datetime.ui" line="381"/>
         <source>UTC</source>
         <translation>UTC</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="433"/>
+        <location filename="datetime.ui" line="421"/>
         <source>Network Time</source>
         <translation>Nätverkstid</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="439"/>
+        <location filename="datetime.ui" line="427"/>
         <source>Move the selected item down</source>
         <translation>Flytta ner det valda objektet</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="450"/>
+        <location filename="datetime.ui" line="438"/>
         <source>Move the selected item up</source>
         <translation>Flytta upp det valda objektet</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="461"/>
+        <location filename="datetime.ui" line="449"/>
         <source>Remove the current item from the list</source>
         <translation>Ta bort det nuvarande objektet från listan</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="472"/>
+        <location filename="datetime.ui" line="460"/>
         <source>Add an item to the list</source>
         <translation>Lägg till ett objekt till listan</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="498"/>
+        <location filename="datetime.ui" line="486"/>
         <source>Automatically update the System Clock with NTP servers:</source>
         <translation>Uppdatera Systemklockan automatiskt  med NTP-servrar:</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="505"/>
+        <location filename="datetime.ui" line="493"/>
         <source>Immediately update the system clock with NTP servers.</source>
         <translation>Uppdatera genast systemklockan med NTP-servrar.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="508"/>
+        <location filename="datetime.ui" line="496"/>
         <source>Update Now</source>
         <translation>Uppdatera Nu</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="520"/>
+        <location filename="datetime.ui" line="505"/>
         <source>List of NTP servers to use.</source>
         <translation>Lista över NTP-servrar att använda.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="536"/>
+        <location filename="datetime.ui" line="521"/>
         <source>Type</source>
         <translation>Typ</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="541"/>
+        <location filename="datetime.ui" line="526"/>
         <source>Address</source>
         <translation>Adress</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="546"/>
+        <location filename="datetime.ui" line="531"/>
         <source>Options</source>
         <translation>Alternativ</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="270"/>
+        <location filename="datetime.cpp" line="270"/>
         <source>Reading...</source>
         <translation>Läser...</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="284"/>
+        <location filename="datetime.cpp" line="284"/>
         <source>Adjusting...</source>
         <translation>Justerar...</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="296"/>
-        <location filename="../datetime.cpp" line="303"/>
+        <location filename="datetime.cpp" line="296"/>
+        <location filename="datetime.cpp" line="303"/>
         <source>System Clock</source>
         <translation>Systemklocka</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="309"/>
+        <location filename="datetime.cpp" line="309"/>
         <source>The %1 time was transferred to the %2.</source>
         <translation>%1 tiden överfördes till %2.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="312"/>
+        <location filename="datetime.cpp" line="312"/>
         <source>The %1 time could not be transferred to the %2.</source>
         <translation>%1 tiden kunde inte överföras till %2.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="350"/>
+        <location filename="datetime.cpp" line="350"/>
         <source>Updating...</source>
         <translation>Uppdaterar...</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="360"/>
+        <location filename="datetime.cpp" line="360"/>
         <source>The system clock was updated successfully.</source>
         <translation>Systemklockan uppdaterades framgångsrikt.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="362"/>
+        <location filename="datetime.cpp" line="362"/>
         <source>The system clock could not be updated.</source>
         <translation>Systemklockan kunde inte uppdateras.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="364"/>
+        <location filename="datetime.cpp" line="364"/>
         <source>None of the NTP servers on the list are currently enabled.</source>
         <translation>Nu är ingen av NTP-servrarna på listan aktiverad.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="595"/>
+        <location filename="datetime.cpp" line="595"/>
         <source>About MX Date &amp; Time</source>
         <translation>Om MX Datum &amp; Tid</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="596"/>
+        <location filename="datetime.cpp" line="596"/>
         <source>Version: </source>
         <translation>Version:</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="597"/>
+        <location filename="datetime.cpp" line="597"/>
         <source>GUI program for setting the time and date in MX Linux</source>
         <translation>Grafiskt program för att ställa in tid och datum i MX Linux</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="599"/>
+        <location filename="datetime.cpp" line="599"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="600"/>
-        <location filename="../datetime.cpp" line="614"/>
+        <location filename="datetime.cpp" line="600"/>
+        <location filename="datetime.cpp" line="614"/>
         <source>License</source>
         <translation>Licens</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="601"/>
+        <location filename="datetime.cpp" line="601"/>
         <source>Changelog</source>
         <translation>Ändringslogg</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="602"/>
+        <location filename="datetime.cpp" line="602"/>
         <source>Cancel</source>
         <translation>Avbryt</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="628"/>
+        <location filename="datetime.cpp" line="628"/>
         <source>&amp;Close</source>
         <translation>&amp;Close</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="646"/>
+        <location filename="datetime.cpp" line="646"/>
         <source>MX Date &amp; Time Help</source>
         <translation>MX Datum &amp; Tid Hjälp</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
